==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/bibtexfileexporterps.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include <qfile.h>
#include <qstringlist.h>

#include <settings.h>
#include <bibtexelement.h>
#include <bibtexfileexporterbibtex.h>
#include "bibtexfileexporterps.h"

namespace BibTeX
{

    BibTeXFileExporterPS::BibTeXFileExporterPS()
            : BibTeXFileExporterToolchain()
    {
        laTeXFilename = QString( workingDir ).append( "/bibtex-to-ps.tex" );
        bibTeXFilename = QString( workingDir ).append( "/bibtex-to-ps.bib" );
        outputFilename = QString( workingDir ).append( "/bibtex-to-ps.ps" );
    }

    BibTeXFileExporterPS::~BibTeXFileExporterPS()
    {
        // nothing
    }

    bool BibTeXFileExporterPS::save( QIODevice* iodevice, BibTeXFile* bibtexfile )
    {
        bool result = FALSE;

        QFile bibtexFile( bibTeXFilename );
        if ( bibtexFile.open( IO_WriteOnly ) )
        {
            BibTeXFileExporter * bibtexExporter = new BibTeXFileExporterBibTeX();
            result = bibtexExporter->save( &bibtexFile, bibtexfile );
            bibtexFile.close();
            delete bibtexExporter;
        }

        if ( result )
            result = generatePS( iodevice );

        return result;
    }

    bool BibTeXFileExporterPS::save( QIODevice* iodevice, BibTeXElement* element )
    {
        bool result = FALSE;

        QFile bibtexFile( bibTeXFilename );
        if ( bibtexFile.open( IO_WriteOnly ) )
        {
            BibTeXFileExporter * bibtexExporter = new BibTeXFileExporterBibTeX();
            result = bibtexExporter->save( &bibtexFile, element );
            bibtexFile.close();
            delete bibtexExporter;
        }

        if ( result )
            result = generatePS( iodevice );

        return result;
    }

    bool BibTeXFileExporterPS::generatePS( QIODevice* iodevice )
    {
        QStringList cmdLines = QStringList::split( '|', "latex bibtex-to-ps.tex|bibtex bibtex-to-ps|latex bibtex-to-ps.tex|latex bibtex-to-ps.tex|dvips -o bibtex-to-ps.ps bibtex-to-ps.dvi" );

        if ( writeLatexFile( laTeXFilename ) && runProcesses( cmdLines ) && writeFileToIODevice( outputFilename, iodevice ) )
            return TRUE;
        else
            return FALSE;
    }

    bool BibTeXFileExporterPS::writeLatexFile( const QString &filename )
    {
        QFile latexFile( filename );
        if ( latexFile.open( IO_WriteOnly ) )
        {
            QTextStream ts( &latexFile );
            ts << "\\documentclass{article}\n";
            ts << "\\usepackage[" << kbibtexsettings.exportlanguage << "]{babel}\n";
            ts << "\\usepackage{url}\n";
            ts << "\\bibliographystyle{" << kbibtexsettings.exportbibliographystyle << "}\n";
            ts << "\\begin{document}\n";
            ts << "\\nocite{*}\n";
            ts << "\\bibliography{bibtex-to-ps}\n";
            ts << "\\end{document}\n";
            latexFile.close();
            return TRUE;
        }
        else
            return FALSE;

    }

}

==> kbibtex-0.1.4.tar.bz2: kbibtex-0.1.4/src/bibtexfileexporterps.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include <qfile.h>
#include <qstringlist.h>

#include <settings.h>
#include <bibtexelement.h>
#include <bibtexfileexporterbibtex.h>
#include "bibtexfileexporterps.h"

namespace BibTeX
{

    BibTeXFileExporterPS::BibTeXFileExporterPS()
            : BibTeXFileExporterToolchain(), m_latexLanguage( "english" ), m_latexBibStyle( "plain" )
    {
        laTeXFilename = QString( workingDir ).append( "/bibtex-to-ps.tex" );
        bibTeXFilename = QString( workingDir ).append( "/bibtex-to-ps.bib" );
        outputFilename = QString( workingDir ).append( "/bibtex-to-ps.ps" );
    }

    BibTeXFileExporterPS::~BibTeXFileExporterPS()
    {
        // nothing
    }

    bool BibTeXFileExporterPS::save( QIODevice* iodevice, BibTeXFile* bibtexfile, QStringList *errorLog )
    {
        bool result = FALSE;

        QFile bibtexFile( bibTeXFilename );
        if ( bibtexFile.open( IO_WriteOnly ) )
        {
            BibTeXFileExporter * bibtexExporter = new BibTeXFileExporterBibTeX();
            result = bibtexExporter->save( &bibtexFile, bibtexfile, errorLog );
            bibtexFile.close();
            delete bibtexExporter;
        }

        if ( result )
            result = generatePS( iodevice, errorLog );

        return result;
    }

    bool BibTeXFileExporterPS::save( QIODevice* iodevice, BibTeXElement* element, QStringList *errorLog )
    {
        bool result = FALSE;

        QFile bibtexFile( bibTeXFilename );
        if ( bibtexFile.open( IO_WriteOnly ) )
        {
            BibTeXFileExporter * bibtexExporter = new BibTeXFileExporterBibTeX();
            result = bibtexExporter->save( &bibtexFile, element, errorLog );
            bibtexFile.close();
            delete bibtexExporter;
        }

        if ( result )
            result = generatePS( iodevice, errorLog );

        return result;
    }

    void BibTeXFileExporterPS::setLaTeXLanguage( const QString& language )
    {
        m_latexLanguage = language;
    }

    void BibTeXFileExporterPS::setLaTeXBibliographyStyle( const QString& bibStyle )
    {
        m_latexBibStyle = bibStyle;
    }

    bool BibTeXFileExporterPS::generatePS( QIODevice* iodevice, QStringList *errorLog )
    {
        QStringList cmdLines = QStringList::split( '|', "latex bibtex-to-ps.tex|bibtex bibtex-to-ps|latex bibtex-to-ps.tex|latex bibtex-to-ps.tex|dvips -o bibtex-to-ps.ps bibtex-to-ps.dvi" );

        if ( writeLatexFile( laTeXFilename ) && runProcesses( cmdLines, errorLog ) && writeFileToIODevice( outputFilename, iodevice ) )
            return TRUE;
        else
            return FALSE;
    }

    bool BibTeXFileExporterPS::writeLatexFile( const QString &filename )
    {
        QFile latexFile( filename );
        if ( latexFile.open( IO_WriteOnly ) )
        {
            QTextStream ts( &latexFile );
            ts.setEncoding( QTextStream::UnicodeUTF8 );
            ts << "\\documentclass{article}\n";
            ts << "\\usepackage[" << m_latexLanguage << "]{babel}\n";
            ts << "\\usepackage{url}\n";
            ts << "\\bibliographystyle{" << m_latexBibStyle << "}\n";
            ts << "\\begin{document}\n";
            ts << "\\nocite{*}\n";
            ts << "\\bibliography{bibtex-to-ps}\n";
            ts << "\\end{document}\n";
            latexFile.close();
            return TRUE;
        }
        else
            return FALSE;

    }

}
